Skip to contents

list_themes() returns a data.frame containing all available themes and their corresponding ids.

Usage

list_themes()

Value

A data.frame

Examples

if (FALSE) { # interactive() && curl::has_internet()
# Get the data frame and show the theme titles
themes <- list_themes()
themes$theme_title
}