R/list.R
list_themes.Rd
list_themes() returns a data.frame containing all available themes and their corresponding ids.
list_themes()
A data.frame
if (FALSE) { # interactive() && curl::has_internet() # Get the data frame and show the theme titles themes <- list_themes() themes$theme_title }